@@ -252,10 +252,16 @@ class FuseSellPipeline:
                 self.logger.info("-" * 40)
                 self.logger.info("TIMING VALIDATION:")
                 if discrepancy_percentage < 5.0:
-                    self.logger.info(f"✅ Timing validation PASSED (discrepancy: {discrepancy_percentage:.1f}%)")
+                    self.logger.info(
+                        f"[OK] Timing validation PASSED (discrepancy: {discrepancy_percentage:.1f}%)"
+                    )
                 else:
-                    self.logger.warning(f"⚠️  Timing validation WARNING (discrepancy: {discrepancy_percentage:.1f}%)")
-                    self.logger.warning(f"   Expected ~{total_stage_time:.2f}s, got {total_duration:.2f}s")
+                    self.logger.warning(
+                        f"[WARN] Timing validation WARNING (discrepancy: {discrepancy_percentage:.1f}%)"
+                    )
+                    self.logger.warning(
+                        f"   Expected ~{total_stage_time:.2f}s, got {total_duration:.2f}s"
+                    )
             
             self.logger.info("=" * 60)
             
@@ -375,6 +381,7 @@ class FuseSellPipeline:
             'team_name': self.config.get('team_name'),
             'project_code': self.config.get('project_code'),
             'staff_name': self.config.get('staff_name', 'Sales Team'),
+            'customer_name': self.config.get('customer_name', ''),
             'language': self.config.get('language', 'english'),
             # Data sources (matching executor schema)
             'input_website': self.config.get('input_website', ''),
@@ -394,6 +401,7 @@ class FuseSellPipeline:
             'reason': self.config.get('reason', ''),
             'recipient_address': self.config.get('recipient_address', ''),
             'recipient_name': self.config.get('recipient_name', ''),
+            'customer_email': self.config.get('customer_email', ''),
             'interaction_type': self.config.get('interaction_type', 'email'),
             'human_action_id': self.config.get('human_action_id', ''),
 
@@ -599,9 +607,11 @@ class FuseSellPipeline:
                 elif stage_name == 'lead_scoring':
                     lead_scores = data.get('scores', [])
                 elif stage_name == 'initial_outreach':
-                    email_drafts.extend(data.get('drafts', []))
+                    drafts = data.get('drafts') or data.get('email_drafts') or []
+                    email_drafts.extend(drafts)
                 elif stage_name == 'follow_up':
-                    email_drafts.extend(data.get('drafts', []))
+                    drafts = data.get('drafts') or data.get('email_drafts') or []
+                    email_drafts.extend(drafts)
         
         # Generate performance analytics
         performance_analytics = self._generate_performance_analytics(duration)
